import React, { useContext, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import Container from 'react-bootstrap/Container';
import Form from 'react-bootstrap/Form';
import Button from 'react-bootstrap/Button';
import UserContext from '../UserContext';
import Swal from 'sweetalert2';

const AddCourse = () => {
  const { user } = useContext(UserContext);
  const navigate = useNavigate();
  const [courseData, setCourseData] = useState({
    name: '',
    description: '',
    price: 0,
    // Add other course-related fields here
  });
  const [isCourseAdded, setCourseAdded] = useState(false);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setCourseData((prevData) => ({
      ...prevData,
      [name]: value,
    }));
  };

  const handleSubmit = async (e) => {
    e.preventDefault();

    try {
      const response = await fetch(`${process.env.REACT_APP_API_URL}/courses/add-course/`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          Authorization: `Bearer ${localStorage.getItem('token')}`, // Assuming you have a token-based authentication
        },
        body: JSON.stringify(courseData),
      });

      if (response.ok) {
        setCourseAdded(true);
        Swal.fire({
          icon: "success",
          title: "Courses added"
        })
      } else {
        console.error('Failed to add the course');
        // Optionally handle error response here
        Swal.fire({
          icon: "error",
          title: "Failed to add the course"
        })
      }
    } catch (error) {
      console.error('Error adding course:', error);
      // Optionally handle network or other errors here
    }
  };

  if (!user || !user.isAdmin) {
    navigate('/');
    return null;
  }

  if (isCourseAdded) {
    navigate('/courses');
    return null;
  }

  return (
    <Container>
      <h2>Add New Course</h2>
      <Form onSubmit={handleSubmit}>
        <Form.Group controlId="name">
          <Form.Label>Course Name</Form.Label>
          <Form.Control
            type="text"
            placeholder="Enter the course name"
            name="name"
            value={courseData.name}
            onChange={handleInputChange}
            required
          />
        </Form.Group>

        <Form.Group controlId="description">
          <Form.Label>Description</Form.Label>
          <Form.Control
            as="textarea"
            placeholder="Enter the course description"
            name="description"
            value={courseData.description}
            onChange={handleInputChange}
            required
          />
        </Form.Group>

        <Form.Group controlId="price">
          <Form.Label>Price</Form.Label>
          <Form.Control
            type="number"
            placeholder="Enter the course price"
            name="price"
            value={courseData.price}
            onChange={handleInputChange}
            required
          />
        </Form.Group>

        {/* Add other form fields for additional course information */}

        <Button variant="primary" type="submit">
          Add Course
        </Button>
      </Form>
    </Container>
  );
};

export default AddCourse;
