import { useEffect, useContext, useState } from 'react';
import { Row, Col } from 'react-bootstrap';
import UserContext from '../UserContext';
import { Navigate } from 'react-router-dom';
import ResetPassword from '../components/ResetPassword';

export default function Profile() {
  const { user } = useContext(UserContext);
  const [profileData, setProfileData] = useState(null);

  useEffect(() => {
    if (user && user.id) {
      // Fetch user profile data when the component mounts
      fetchUserProfile();
    }
  }, [user]);

  const fetchUserProfile = async () => {
    try {
      const response = await fetch(
        `${process.env.REACT_APP_API_URL}/users/details`,
        {
          headers: {
            Authorization: `Bearer ${localStorage.getItem('token')}`,
          },
        }
      );

      if (response.ok) {
        const data = await response.json();
        console.log('Profile Data:', data);

        if (data && data.firstName && data.lastName && data.email && data.mobileNo) {
          setProfileData(data);
        } else {
          console.error('Invalid user profile data received from the server.');
        }
      } else {
        console.error('Failed to fetch user profile');
      }
    } catch (error) {
      console.error('Error fetching user profile:', error);
    }
  };

  if (!user || user.id === null) {
    return <Navigate to="/courses" />;
  }

  return (
    <>
    <Row>
      <Col className="p-5 bg-primary text-white">
        <h1 className="my-5">Profile</h1>
        {profileData ? (
          <>
            <h2 className="mt-3">
              {profileData.firstName} {profileData.lastName}
            </h2>
            <hr />
            <h4>Contacts</h4>
            <ul>
              <li>
                Name: {profileData.firstName} {profileData.lastName}
              </li>
              <li>Email: {profileData.email}</li>
              <li>Mobile No: {profileData.mobileNo}</li>
            </ul>
          </>
        ) : (
          <p>Loading profile...</p>
        )}
      </Col>
    </Row>

			<Row className="pt-4 mt-4">
				<Col>
					<ResetPassword />
				</Col>
			</Row>
    </>
  );
}
